body {
    font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol" !important;
    color: #33455a;
}

a{
    color: #6e829b !important;
}
a:hover{
    text-decoration: none;
}

h1, h2, h3, h4, h5, h6, .panel .panel-heading i {
    font-weight: inherit;
    color: #3d5170;
}

.navbar{
    background-color: white;
}

.navbar .navbar-brand{
    color: inherit;
}

.navbar .icon-bar{
    background-color: #6e829b !important;
}

.navbar-top-links > li > a:hover, .navbar-top-links > li > a:focus, .navbar-top-links > .open > a, .navbar-top-links > .open > a:hover, .navbar-top-links > .open > a:focus {
    color: #6e829b !important;
}

.nav>li>a:hover, .nav>li>a:focus{
    background-color: inherit !important;
}

.sidebar ul li:not(:first-child) {
    border-top: 1px solid white;
}

.sidebar .main-menu a i{
    height: 24px;
    font-size: 23px;
}

.form-control, .btn, .input-group-addon, .select2-selection, .alert, .panel {
    border-radius: 0 !important;
}

.panel{
    -webkit-box-shadow: none !important;
    box-shadow: none !important;
}

.table > thead > tr > th, .table > thead > tr > td {
    border-bottom-width: 1px !important;
}

.btn-default{
    border: 1px solid #e1e5eb !important;
    color: #3d5170 !important;
}

.btn-default:hover, .pagination>.active>a{
    background-color: white;
    box-shadow: 0 0.125rem 0.625rem rgba(129,142,163,.2), 0 0.0625rem 0.125rem rgba(129,142,163,.3);

}

.fc-content {
    background-color: #FFF !important;
}

.dropdown-menu>li>a:hover, .dropdown-menu>li>a:focus{
    background: inherit;
}

.dropdown a i, .navbar-top-links a i{
    font-size: 18px;
}

#user-drop-down li.divider{
    padding: 0;
}

#user-drop-down li, .dropdown-alerts li{
    padding: 7px;
}


.badge{
    background-color: #BBB;
}
.badge-primary, .progress-bar{
    background-color: #3d5170;
}

.timeline{
    border-top: 2px solid #6e829b;
}

.timeline__step-label{
	border-color: #6e829b;
}

.timeline__step-label:before {
	border-top-color: #6e829b;
}

.timeline__step-marker{
	border: 4px solid #6e829b;
	color: #6e829b;
}

.timeline__step.done .timeline__step-marker{
	background: #6e829b;
}

.progress{
	background-color: #6e829b;
}

#wrapper {
    width: 100%;
}

.panel-default>.panel-heading{
    background-color: white;
}






.label-checkbox {
    padding-top: 5px
}

input[type=checkbox], input[type=radio] {
    opacity: 0;
    position: absolute;
    width: 15px;
    height: 15px;
    z-index: 2;
    cursor: pointer
}

input[type=radio] {
    margin-top: 0
}

input[type=checkbox]:checked + .custom-checkbox, input[type=radio]:checked + .custom-radio {
    background-color: #f5f8fc
}

input[type=checkbox] + .custom-checkbox, input[type=checkbox]:disabled + .custom-checkbox, input[type=radio] + .custom-radio, input[type=radio]:disabled + .custom-radio {
    display: inline-block;
    position: relative;
    line-height: 13px;
    background-color: #fafafa;
    margin-right: 3px;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px
}

input[type=checkbox]:hover + .custom-checkbox, input[type=radio]:hover + .custom-radio {
    box-shadow: 0 0 10px rgba(0, 0, 0, .1);
    -moz-box-shadow: 0 0 10px rgba(0, 0, 0, .1);
    -webkit-box-shadow: 0 0 10px rgba(0, 0, 0, .1)
}

input[type=checkbox] + .custom-checkbox:before {
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px
}

input[type=checkbox]:disabled + .custom-checkbox, input[type=radio]:disabled + .custom-radio {
    background-color: #ccc;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px
}

input[type=checkbox] + .custom-checkbox, input[type=radio] + .custom-radio {
    display: inline-block;
    font-family: fontAwesome;
    font-size: 12px;
    content: "";
    border: 1px solid #ccc;
    box-shadow: 0 1px 2px rgba(0, 0, 0, .05);
    text-align: center;
    width: 17px;
    height: 17px;
    line-height: 15px;
    vertical-align: middle
}

input[type=checkbox]:checked + .custom-checkbox:before {
    content: '\f00c';
    border-color: rgba(0, 0, 0, .2);
    font-size: 12px;
    color: #7a7a7a;
    box-shadow: 0 1px 2px rgba(0, 0, 0, .05), inset 0 -15px 10px -12px rgba(0, 0, 0, .05), inset 15px 10px -12px rgba(255, 255, 255, .1);
    text-shadow: 0 1px #fff
}

input[type=radio] + .custom-radio, input[type=radio]:disabled + .custom-radio {
    border-radius: 50em;
    -moz-border-radius: 50em;
    -webkit-border-radius: 50em;
    line-height: 0
}

input[type=radio] + .custom-radio:before {
    border-radius: 50em;
    -moz-border-radius: 50em;
    -webkit-border-radius: 50em
}

input[type=radio]:checked + .custom-radio:before {
    content: '';
    position: absolute;
    display: block;
    width: 11px;
    height: 11px;
    top: 2px;
    left: 2px;
    background-color: #777;
    border-color: #adb8c0;
    box-shadow: 0 1px 2px rgba(0, 0, 0, .05), inset 0 -15px 10px -12px rgba(0, 0, 0, .05), inset 15px 10px -12px rgba(255, 255, 255, .1);
    text-shadow: 0 1px #fff
}

input[type=radio]:checked + .custom-radio.blue:before {
    color: #09C
}

input[type=checkbox]:disabled:active + .custom-checkbox, input[type=radio]:disabled:active + .custom-radio {
    box-shadow: none;
    -moz-box-shadow: none;
    -webkit-box-shadow: none
}

input[type=checkbox]:active + .custom-checkbox, input[type=radio]:active + .custom-radio {
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    box-shadow: inset 0 2px 3px rgba(0, 0, 0, .1);
    -moz-box-shadow: inset 0 2px 3px rgba(0, 0, 0, .1);
    -webkit-box-shadow: inset 0 2px 3px rgba(0, 0, 0, .1)
}


header{
 box-shadow: 0 0.125rem 0.625rem rgba(90,97,105,.12);
 height: 67.5px !important;
}


.navbar-top-links li a{
 padding: 25px !important;
}

.notification-label{
 top: 20px !important;
 right: 30px !important;
}

.navbar-brand{
 padding: 7px 25px !important;
}

#menu-toggle{
 margin: 15px !important;
}

#page-wrapper{
 margin-top: 68px !important;
}


aside .nav>li>a i{
color: #cacedb !important;
    margin-left: 5px;
    margin-right: 10px;
}

aside .nav>li>a{
    color: #3d5170 !important;
    font-size: 110%;
    border-bottom: 1px solid #e1e5eb;
    margin: 5px;
}
aside .nav>li>a.active{
    color: #3d5170 !important;
    font-weight: 500;
}
aside .nav>li>a.active i{
    color: #3d5170 !important;
}

.breadcrumb, #page-wrapper{
    background-color: #f5f6f8 !important;
}

.table-responsive, .card-panel-item{
    background-color: #fff;
}

.shortcut-wrapper{
    border: None;
}

.paginator .table-responsive th{
    height: 44px;
    padding-top: 20px !important;
    padding-bottom: 20px !important;
}
.paginator .table-responsive .table td{
    padding-top: 15px !important;
    padding-bottom: 15px !important;
}
.panel-heading{
    height: 64px !important;
    padding: 20px !important;
}

.btn-default[type="submit"]{
    background-color: transparent;
    background-image: none;
    border-color: #3d5170 !important;
    color: #3d5170 !important;
}
.btn-default[type="submit"]:hover {
    color: #fff !important;
    background-color: #3d5170;
    border-color: #3d5170;
    box-shadow: 0 5px 15px rgba(0,0,0,.05), 0 4px 10px rgba(0,123,255,.25);
}

.navbar-brand {
    font-weight: 500;
    color: #3d5170 !important;
    font-size: 24px;
}

.paginator-admin .panel-body{
    background-color: #fff;
    padding-top: 10px;
    padding-left: 15px;
    padding-right: 15px;
    padding-bottom: 15px;
    margin-top: 5px;
}

.pagination>.active>a:hover{
    background-color: #fff;
}

.padding-md{
    padding: 15px;
}





