/* Lion Theme */

body {
    background-color: rgba(197, 171, 133, 0.2);
}
body,
a,
a:active {
    color: #050505;
}
a:hover,
header .navbar-header a:hover {
    color: #6e7271;
}
h2 .fa {
    color: #c5Ab85;
}
h2 .fa {
    font-size: 80%;
    margin-right: 5px;
    vertical-align: 0;
}
header.navbar {
    background-color: rgba(197, 171, 133, 0.8);
    border: 0 none;
    border-bottom: 1px solid #050505;
    min-height: 40px;
}
body#login-body h2 a {
    color: #c5ab85;
    font-weight: 100;
    letter-spacing: 2px;
    text-transform: uppercase;
}
body#login-body .panel {
    background-color: rgba(197, 171, 133, 0.2);
}
#page-wrapper {
    background-color: transparent;
    border-color: #c5ab85;
    margin-top: 40px;
}
#user-drop-down {
    background-color: #050505;
}
#wrapper {
    background-color: transparent;
}
.action-links > a {
    margin: 0 2px;
}
.badge {
    background-color: #c5Ab85;
}
.breadcrumb {
    background-color: transparent;
    padding: 40px 40px 10px;
}
.btn-default {
    background-color: #050505;
    border: 0 none;
    color: #f8f4e3;
}
.btn-default:hover {
    background-color: #c5Ab85;
    color: #050505;
}
.btn-default .fa {
    color: #f8f4e3;
    margin-right: 10px;
}
.btn-default:hover .fa {
    color: #050505;
}
.card-panel {
    border-bottom: 1px solid #c5Ab85;
    flex-basis: 190px;
    min-width: 190px;
    padding-bottom: 0;
    padding-right: 0;
}
.card-panel > a:hover {
    text-decoration: none;
}
.card-panel-item {
    background-color: transparent;
    padding: 40px;
}
.card-panel-item .stat-icon {
    color: #6e7271;
    float: none;
    font-size: 170%;
    line-height: 1.4em;
    text-align: center;
    width: 100%;
}
.card-panel-item .pull-right {
    float: none !important;
}
.card-panel-item .title {
    font-size: 110%;
    font-weight: 900;
    margin-top: 0;
    text-align: center;
    text-transform: uppercase;
}
.card-panel-item .value {
    color: #c5Ab85;
    font-weight: 100;
    margin-top: -10px;
    text-align: center;
}
.copyright {
    border-top: 1px solid #c5Ab85;
    margin: 0;
    padding: 40px 40px 20px;
}
.dashboard-aside,
.dashboard-header,
.dashboard-main,
.dashboard-footer {
    margin-left: 0;
    margin-right: 0;
}
.dashboard-header {
    background-color: rgba(197, 171, 133, 0.3);
    border-bottom: 1px solid #c5Ab85;
}
.dashboard-aside {
    background-color: rgba(197, 171, 133, 0.05);
}
.dashboard-main + .dashboard-aside-1,
.dashboard-aside-1 + .dashboard-aside-2 {
    border-right: 1px solid #c5Ab85;
}
.dashboard-main + .dashboard-aside-1 + .dashboard-aside-2,
.dashboard-main + .dashboard-aside-2 {
    border-left: 1px solid #c5Ab85;
}
.dashboard-footer {
    border-top: 1px solid #c5Ab85;
}
.dashboard-main .panel:last-of-type,
.dashboard-main .panel:only-of-type,
.dashboard-footer .panel:last-of-type,
.dashboard-footer .panel:only-of-type {
    border-bottom: 0 none;
}
.dropdown-menu .divider {
    background-color: #111;
    margin: 0;
}
.fc td,
.fc th {
    border-color: rgba(197, 171, 133, 0.5) !important;
}
.fc .fc-center h2 {
    font-size: 130%;
}
.filter-container button,
.paginator .filter-container input {
    height: 38px !important;
}
.filter-container button {
    background-color: #fff;
    border: 1px solid #050505;
    height: 38px !important;
}
.filter-container button .fa {
    color: #c5ab85;
    margin-right: 0;
}
.form-control {
    border: 1px solid #6e7271;
    border-radius: 0;
    height: 38px;
}
.image-rows-container {
    border: 0 none;
    margin-bottom: 0;
    padding: 20px;
}
aside .nav > li > a {
    border-top: 1px solid #c5ab85;
    color: #050505;
    font-size: 90%;
    font-weight: 900;
    padding: 15px 20px;
    text-transform: uppercase;
}
aside .nav > li > a:active,
aside .nav > li > a:focus,
aside .nav > li > a:hover,
aside .nav > li > a.active {
    background-color: rgba(197, 171, 133, 0.2);
    color: #050505;
}
aside .nav > li > a .fa {
    color: #c5Ab85;
    font-size: 140%;
    margin-right: 10px;
    vertical-align: -2px;
}
aside .nav > li > a span.fa {
    margin-top: -4px;
}
aside .nav > li > a:hover .fa,
aside .nav > li > a.active .fa {
    color: #050505;
}
.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
    background-color: transparent;
    border-color: #6e7271
}
.navbar .icon-bar {
    background-color: #050505;
}
.navbar-brand {
    font-size: 45%;
    font-weight: 300;
    height: 40px;
    letter-spacing: 1px;
    line-height: 40px;
    padding-left: 0;
    text-transform: uppercase;
}
.navbar-header img {
    height: 30px;
    margin-top: 0;
}
.navbar-toggle {
    padding-bottom: 4px;
    padding-top: 4px;
}
.navbar-toggle .icon-bar {
    height: 1px;
    width: 14px;
}
.navbar-top-links li a {
    border-left: 1px solid #6e7271;
    color: #050505;
    min-height: 40px;
    padding: 10px 15px;
}
.navbar-top-links li a:active,
.navbar-top-links li a:focus,
.navbar-top-links li a:hover {
    background-color: transparent;
    color: #6e7271;
}
.navbar-top-links .dropdown-alerts {
    background-color: #050505;
}
.navbar-top-links .dropdown-menu li a {
    border: 0 none;
    color: #f8f4e3;
    display: block;
    padding: 5px 15px;
}
.navbar-top-links .dropdown-menu li a:hover {
    background-color: #050505;
    text-decoration: none;
}
.navbar-top-links .dropdown-menu li a:hover {
    color: #c5ab85;
}
.navbar-top-links .dropdown-menu li a .fa {
    color: #c5ab85;
    margin-right: 10px;
}
.navbar-top-links .dropdown-menu li a span.small {
    color: #6e7271;
    margin-top: 3px;
}
.navbar-top-links .dropdown-menu .divider {
    background-color: #6e7271;
}
.paginator .paginator-tabs .active .badge {
    background-color: #050505;
}
.pagination > li > a,
.pagination > li > span {
    background-color: transparent;
    border: 0 none;
    color: #050505;
}
.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
    background-color: #050505;
    border-color: #050505;
}
.pagination > .disabled > span,
.pagination > .disabled > span:hover,
.pagination > .disabled > span:focus,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
    background-color: transparent;
    border-color: transparent;
}
.paginator-actions.pull-right > .btn {
    font-size: 90%;
    margin-left: 5px;
    margin-top: 5px;
    padding: 5px 12px;
}
.paginator-actions.pull-right > .btn .fa {
    font-size: 105%;
}
.panel {
    background-color: transparent;
    border: 0 none;
    border-bottom: 1px solid #c5ab85;
    border-radius: 0;
    box-shadow: 0 0 0;
    margin-bottom: 0;
}
.row .panel {
    background-color: rgba(197, 171, 133, 0.2);
    border: 1px solid #c5ab85;
    margin-bottom: 15px;
    margin-top: 15px;
}
.panel.panel-default .panel-heading {
    background-color: transparent;
    border: 0 none;
    color: #6e7271;
    font-size: 110%;
    font-weight: 500;
    overflow: hidden;
    padding: 40px 40px 0;
    position: relative;
    text-align: left;
}
.panel.panel-default .panel-heading .fa {
    color: #c5Ab85;
    float: left;
    font-size: 100%;
    margin-right: 14px;
    margin-top: 2px;
    vertical-align: 0;
}
.panel.panel-default .panel-heading .fa.fa-expand {
    background-color: transparent;
    color: #6e7271;
    float: right;
    font-size: 90%;
    margin-left: 0;
    margin-right: 0;
    opacity: 0.5;
    position: absolute;
    right: 10px;
    top: 10px;
}
.panel.notification-panel .panel-body {
    padding-top: 0;
}
.panel.notification-panel .panel-body > a:hover {
    text-decoration: none;
}
.panel.notification-panel .panel-body span:first-child {
    color: #c5ab85;
    font-size: 900%;
    font-weight: 100;
    margin-top: 10px;
}
.panel.notification-panel .panel-body a:hover span:first-child {
    color: #6e7271;
}
.panel.notification-panel .panel-body span:last-child {
    font-size: 110%;
    font-weight: 900;
    text-transform: uppercase;
}
.panel-body {
    background-color: transparent;
    padding: 40px;
}
main .padding-md {
    padding: 0 40px;
}
.select2-container .select2-selection--single {
    height: 38px !important;
}
.select2-container--default .select2-selection--single {
    border-radius: 0 !important;
}
.select2-selection {
    min-height: 38px !important;
    border: 1px solid #050505 !important;
}
.shortcut-wrapper {
    border: 0 none;
    margin-bottom: 0;
    padding: 0;
    text-align: left;
}
.shortcut-wrapper .shortcut-link {
    border-right: 1px solid #c5Ab85;
    flex-grow: 1;
    margin: 0;
    padding: 20px 30px;
}
.shortcut-wrapper .shortcut-link .shortcut-icon {
    color: #c5Ab85;
    float: left;
    font-size: 115%;
    margin-right: 10px;
    margin-top: -3px;
}
.shortcut-wrapper .shortcut-description {
    font-size: 90%;
    font-weight: 900;
    padding-top: 0;
    text-transform: uppercase;
}
.sidebar {
    background-color: transparent;
}
.sidebar .nav-second-level li a {
    padding-bottom: 7px;
    padding-left: 60px;
    padding-top: 7px;
}
.sidebar .sidebar-search {
    margin-bottom: 15px;
}
.sidebar-profile {
    border-bottom: 1px solid #050505;
    color: #050505;
    margin: 5px 15px 15px;
    overflow: hidden;
}
.table > tbody > tr:nth-child(odd) > td,
.image-rows-row:nth-child(odd) {
    background-color: rgba(197, 171, 133, 0.2);
}
.table > tbody > tr:nth-child(even) > td,
.image-rows-row:nth-child(even) {
    background-color: rgba(197, 171, 133, 0.05);
}
.table > thead > tr > th,
.table > tbody > tr > th,
.table > tfoot > tr > th,
.table > thead > tr > td,
.table > tbody > tr > td,
.table > tfoot > tr > td {
    padding: 10px;
}
.table > thead > tr > th {
    background-color: transparent;
    border: 0 none;
    color: #6e7271;
    font-weight: 600;
}
.table > thead > tr > th a {
    color: #6e7271;
}
.table > tbody > tr > td {
    background-color: #f8f4e3;
    border: 0 none;
}
.table-responsive {
    background-color: rgba(197, 171, 133, 0.1);
    padding: 20px;
}