<div class="paginator-image-rows">
    {% for obj in self.get_queryset %}
        <div class="image-rows-row">
            <div class="image-rows-container">
                {% for verbose_name, lookup, sortable, to in self.column_names %}
                    <div>
                        {% if forloop.first  %}
                            <p class="image-rows-title">
                                {% paginator_checkboxes self obj False %}
                                {{ obj|getattr:lookup|format }}
                            </p>
                        {% else %}
                            <p>{{ verbose_name }} : {{ obj|getattr:lookup|format }}</p>
                        {% endif %}

                        {% if forloop.last %}
                        <div class="pull-right paginator-actions">
                            {% paginator_icons self obj True %}
                            {% add_actions self obj %}
                            {{ self.drop_down }}
                        </div>
                        {% endif %}
                    </div>
                {% endfor %}
            </div>
        </div>
    {% endfor %}
</div>
