
{% if "static" not in widget.value.url %}
{% if widget.is_initial %}
    <br>{{ widget.initial_text }}: <a target="_blank" href="{{ widget.value.url }}">{{ widget.value }}</a>{% if not widget.required %}
    <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" />
        <span class="custom-checkbox"></span>
    <label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label>{% endif %}<br />
    {{ widget.input_text }}:
{% endif %}
{% endif %}
<br>
<input type="{{ widget.type }}" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %} />
