{% if self.as_pdf %}{% else %}
<div class="panel panel-default notification-panel">
        <div class="panel-heading clearfix">
            <span><i class="fa {{ self.icon }}"></i></span>
            <span>{{ self.title }}</span>
        </div>
    <div class="panel-body">
        <a class="ajax" href="{{ self.url }}">
            <span>{{ self.count }}</span>
            <span>{{ self.description }}</span>
        </a>
    </div>
</div>
{% endif %}
