/* Zebra Theme */

body {
    background-color: #fff;
    color: #000;
}
a,
a:active {
    color: #000;
}
a:hover {
    color: #666;
}
h2 .fa {
    color: #666;
    font-size: 80%;
    margin-right: 5px;
    vertical-align: 0;
}
header.navbar {
    background-color: #000;
}
#page-wrapper,
.breadcrumb {
    background-color: #f5f6f8;
}
.action-links > a {
    margin: 0 2px;
}
.breadcrumb {
    padding: 40px 40px 10px;
}
.dashboard-main {
    margin-left: 40px;
    margin-right: 40px;
}
.dashboard-aside-2 {
    padding-right: 40px;
}
.fc .fc-center h2 {
    font-size: 130%;
}
aside .nav > li > a {
    padding: 12px 20px;
}
aside .nav > li > a:hover {
    background-color: #000;
    color: #fff;
}
aside .nav > li > a .fa {
    color: #666;
    font-size: 120%;
    margin-right: 5px;
}
.navbar .icon-bar {
    background-color: #aaa;
}
.navbar-brand {
    padding-bottom: 10px;
    padding-left: 0;
    padding-top: 10px;
}
.navbar-header img {
    height: 30px;
    margin-top: 0;
}
.navbar-top-links li a {
    color: #fff;
}
.navbar-top-links li a:hover {
    color: #000;
}
.pagination > li > a,
.pagination > li > span {
    background-color: transparent;
    border: 0 none;
    color: #000;
}
.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
    background-color: #000;
    border-color: #000;
}
.pagination > .disabled > span,
.pagination > .disabled > span:hover,
.pagination > .disabled > span:focus,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
    background-color: transparent;
    border-color: transparent;
}
.panel {
    border: 0 none;
    border-radius: 0;
}
.panel.panel-default .panel-heading {
    background-color: #000;
    border: 0 none;
    color: #fff;
    font-size: 100%;
    font-weight: 400;
    padding: 10px 20px;
    text-transform: uppercase;
}
.panel.panel-default .panel-heading .fa {
    color: #aaa;
    font-size: 80%;
    margin-right: 5px;
    vertical-align: 0;
}
.padding-md {
    padding: 0 40px;
}
.sidebar {
    background-color: #fff;
}
.sidebar .nav-second-level li a {
    padding-bottom: 7px;
    padding-left: 50px;
    padding-top: 7px;
}
.table > thead > tr > th {
    background-color: #000;
    border: 0 none;
    color: #fff;
    font-weight: 400;
}
.table > thead > tr > th a {
    color: #fff;
}
.table > tbody > tr > td {
    background-color: #fff;
    border: 0 none;
}
.table > tbody > tr:nth-child(even) > td {
    background-color: #f5f6f8;
}