# -*- coding: utf-8 -*-

# Generated by Django 1.11 on 2018-01-06 19:21


from django.db import migrations
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0013_auto_20170910_1543'),
    ]

    operations = [
        migrations.AlterField(
            model_name='organization',
            name='ascii',
            field=djangoplus.db.models.fields.SearchField(blank=True, default=b'', editable=False),
        ),
        migrations.AlterField(
            model_name='unit',
            name='ascii',
            field=djangoplus.db.models.fields.SearchField(blank=True, default=b'', editable=False),
        ),
    ]
